@@ -29,6 +29,7 @@
 #include "banshee-player-pipeline.h"
 #include "banshee-player-cdda.h"
 #include "banshee-player-video.h"
+#include "banshee-player-equalizer.h"
 #include "banshee-player-missing-elements.h"
 
 // ---------------------------------------------------------------------------
@@ -75,7 +76,7 @@ bp_pipeline_bus_callback (GstBus *bus, GstMessage *message, gpointer userdata)
             GstState old, new, pending;
             gst_message_parse_state_changed (message, &old, &new, &pending);
             
-            //_bp_missing_elements_handle_state_changed (player, old, new);
+            _bp_missing_elements_handle_state_changed (player, old, new);
             
             if (player->state_changed_cb != NULL) {
                 player->state_changed_cb (player, old, new, pending);
@@ -174,9 +175,8 @@ _bp_pipeline_construct (BansheePlayer *player)
     GstPad *teepad;
     GstElement *audiosink;
     GstElement *audiosinkqueue;
-    //GstElement *audioconvert, *audioconvert2;
-    //GstElement *capsfilter = NULL;
-    //gboolean buggy_eq = FALSE;
+    GstElement *eq_audioconvert = NULL;
+    GstElement *eq_audioconvert2 = NULL;
     
     g_return_val_if_fail (IS_BANSHEE_PLAYER (player), FALSE);
     
@@ -213,46 +213,23 @@ _bp_pipeline_construct (BansheePlayer *player)
     audiosinkqueue = gst_element_factory_make ("queue", "audiosinkqueue");
     g_return_val_if_fail (audiosinkqueue != NULL, FALSE);
 
-    /*audioconvert = gst_element_factory_make ("audioconvert", "audioconvert");
-    audioconvert2 = gst_element_factory_make ("audioconvert", "audioconvert2");
-    player->equalizer = gst_element_factory_make ("equalizer-10bands", "equalizer-10bands");
-    player->preamp = gst_element_factory_make ("volume", "preamp");
-
-    // Workaround for equalizer bug that caused clipping when processing integer samples
+    player->equalizer = _bp_equalizer_new (player);
+    player->preamp = NULL;
     if (player->equalizer != NULL) {
-        GstElementFactory *efactory = gst_element_get_factory (player->equalizer);
-
-        buggy_eq = !gst_plugin_feature_check_version (GST_PLUGIN_FEATURE (efactory), 0, 10, 9);
-
-        if (buggy_eq) {
-            GstCaps *caps;
-
-            capsfilter = gst_element_factory_make ("capsfilter", "capsfilter");
-            caps = gst_caps_new_simple ("audio/x-raw-float", NULL);
-            g_object_set (capsfilter, "caps", caps, NULL);
-            gst_caps_unref (caps);
-        }
-    }*/
-
+        eq_audioconvert = gst_element_factory_make ("audioconvert", "audioconvert");
+        eq_audioconvert2 = gst_element_factory_make ("audioconvert", "audioconvert2");
+        player->preamp = gst_element_factory_make ("volume", "preamp");
+    }
+    
     // Add elements to custom audio sink
     gst_bin_add (GST_BIN (player->audiobin), player->audiotee);
     
-    /*if (player->equalizer != NULL) {
-        gst_bin_add (GST_BIN (player->audiobin), audioconvert);
-        gst_bin_add (GST_BIN (player->audiobin), audioconvert2);
-
-        if (buggy_eq) {
-            gst_bin_add (GST_BIN (player->audiobin), capsfilter);
-        }
-        
+    if (player->equalizer != NULL) {
+        gst_bin_add (GST_BIN (player->audiobin), eq_audioconvert);
+        gst_bin_add (GST_BIN (player->audiobin), eq_audioconvert2);
         gst_bin_add (GST_BIN (player->audiobin), player->equalizer);
         gst_bin_add (GST_BIN (player->audiobin), player->preamp);
-    } else {
-        g_object_unref (player->preamp);
-        player->preamp = NULL;
-        g_object_unref (audioconvert);
-        g_object_unref (audioconvert2);
-    }*/
+    }
     
     gst_bin_add (GST_BIN (player->audiobin), audiosinkqueue);
     gst_bin_add (GST_BIN (player->audiobin), audiosink);
@@ -267,19 +244,14 @@ _bp_pipeline_construct (BansheePlayer *player)
         gst_element_get_pad (audiosinkqueue, "sink"));
 
     // Link the queue and the actual audio sink
-    /*if (player->equalizer != NULL) {
+    if (player->equalizer != NULL) {
         // link in equalizer, preamp and audioconvert.
-        if (buggy_eq) {
-            gst_element_link_many (audiosinkqueue, audioconvert, player->preamp, 
-                player->equalizer, audioconvert2, audiosink, NULL);
-        } else {
-            gst_element_link_many (audiosinkqueue, audioconvert, capsfilter, 
-                player->preamp, player->equalizer, audioconvert2, audiosink, NULL);
-        }
-    } else {*/
+        gst_element_link_many (audiosinkqueue, eq_audioconvert, player->preamp, 
+            player->equalizer, eq_audioconvert2, audiosink, NULL);
+    } else {
         // link the queue with the real audio sink
         gst_element_link (audiosinkqueue, audiosink);
-    //}
+    }
     
     // Now that our internal audio sink is constructed, tell playbin to use it
     g_object_set (G_OBJECT (player->playbin), "audio-sink", player->audiobin, NULL);
