@@ -81,6 +81,7 @@ struct BansheePlayer {
     GstElement *audiobin;
     GstElement *equalizer;
     GstElement *preamp;
+    gint equalizer_status;
     
     // Pipeline/Playback State
     GMutex *mutex;
@@ -98,7 +99,8 @@ struct BansheePlayer {
     // Plugin Installer State
     GdkWindow *window;
     GSList *missing_element_details;
-    gboolean install_plugins_noprompt;
+    GSList *missing_element_details_handled;
+    gboolean handle_missing_elements;
     #ifdef HAVE_GST_PBUTILS
     GstInstallPluginsContext *install_plugins_context;
     #endif
