@@ -154,7 +154,7 @@ namespace Nereid
             seek_slider.Show ();
             ActionService.PopulateToolbarPlaceholder (header_toolbar, "/HeaderToolbar/SeekSlider", seek_slider);
             
-            TrackInfoDisplay track_info_display = new TrackInfoDisplay ();
+            TrackInfoDisplay track_info_display = new ClassicTrackInfoDisplay ();
             track_info_display.Show ();
             ActionService.PopulateToolbarPlaceholder (header_toolbar, "/HeaderToolbar/TrackInfoDisplay", track_info_display, true);
             
@@ -280,6 +280,7 @@ namespace Nereid
             view_container.SearchEntry.Ready = true;
         }
         
+        private Source previous_source = null;
         private TrackListModel previous_track_model = null;
         private void OnActiveSourceChanged (SourceEventArgs args)
         {
@@ -313,10 +314,42 @@ namespace Nereid
                 previous_track_model = (source as ITrackModelSource).TrackModel;
                 previous_track_model.Reloaded += HandleTrackModelReloaded;
             }
-
+            
+            if (previous_source != null) {
+                previous_source.Properties.PropertyChanged -= OnSourcePropertyChanged;
+            }
+            
+            previous_source = source;
+            previous_source.Properties.PropertyChanged += OnSourcePropertyChanged;
+            
+            UpdateSourceContents (source);
+            
+            UpdateSourceInformation ();
+            view_container.SearchEntry.Ready = true;
+        }
+        
+        private void OnSourcePropertyChanged (object o, PropertyChangeEventArgs args)
+        {
+            if (args.PropertyName == "Nereid.SourceContents") {
+                UpdateSourceContents (previous_source);
+            }
+        }
+        
+        private void UpdateSourceContents (Source source)
+        {
+            if (source == null) {
+                return;
+            }
+            
             // Connect the source models to the views if possible
-            if (source.Properties.Contains ("Nereid.SourceContents")) {
-                view_container.Content = source.Properties.Get<ISourceContents> ("Nereid.SourceContents");
+            ISourceContents contents = source.GetInheritedProperty<bool> ("Nereid.SourceContentsPropagate")
+                ? source.GetInheritedProperty<ISourceContents> ("Nereid.SourceContents")
+                : source.Properties.Get<ISourceContents> ("Nereid.SourceContents");
+            
+            if (contents != null) {
+                if (view_container.Content != contents) {
+                    view_container.Content = contents;
+                }
                 view_container.Content.SetSource (source);
                 view_container.Show ();
             } else if (source is ITrackModelSource) {
@@ -339,8 +372,6 @@ namespace Nereid
             if (view_container.Visible && view_container.Content is ITrackModelSourceContents) {
                 ITrackModelSourceContents track_content = view_container.Content as ITrackModelSourceContents;
                 source.Properties.Set<IListView<TrackInfo>>  ("Track.IListView", track_content.TrackView);
-                source.Properties.Set<IListView<ArtistInfo>> ("Artist.IListView", track_content.ArtistView);
-                source.Properties.Set<IListView<AlbumInfo>>  ("Album.IListView", track_content.AlbumView);
             }
 
             view_container.Header.Visible = source.Properties.Contains ("Nereid.SourceContents.HeaderVisible") ?
@@ -356,9 +387,6 @@ namespace Nereid
             if (footer_widget != null) {
                 view_container.SetFooter (footer_widget);
             }
-            
-            UpdateSourceInformation ();
-            view_container.SearchEntry.Ready = true;
         }
 
         private void OnSourceUpdated (SourceEventArgs args)
@@ -437,6 +465,10 @@ namespace Nereid
             source_view.ResetHighlight ();
         }
 
+        public override Box ViewContainer {
+            get { return view_container; }
+        }
+
 #endregion
         
 #region Gtk.Window Overrides
