@@ -1,4 +1,4 @@
-//
+
 // TrackInfo.cs
 //
 // Author:
@@ -38,8 +38,11 @@ using Banshee.Streaming;
 
 namespace Banshee.Collection
 {
-    public class TrackInfo : ITrackInfo
+    public class TrackInfo : CacheableItem, ITrackInfo
     {
+        public delegate bool IsPlayingHandler (TrackInfo track);
+        public static IsPlayingHandler IsPlayingMethod;
+            
         private SafeUri uri;
         private SafeUri more_info_uri;
         private string mimetype;
@@ -47,6 +50,7 @@ namespace Banshee.Collection
 
         private string artist_name;
         private string album_title;
+        private string album_artist;
         private string track_title;
         private string genre;
         private string composer;
@@ -115,6 +119,10 @@ namespace Banshee.Collection
         public virtual void Save ()
         {
         }
+        
+        public bool IsPlaying {
+            get { return (IsPlayingMethod != null) ? IsPlayingMethod (this) : false; }
+        }
 
         public virtual SafeUri Uri {
             get { return uri; }
@@ -146,6 +154,11 @@ namespace Banshee.Collection
             set { album_title = value; }
         }
 
+        public virtual string AlbumArtist {
+            get { return album_artist ?? ArtistName; }
+            set { album_artist = value; }
+        }
+
         public virtual string TrackTitle {
             get { return track_title; }
             set { track_title = value; }
@@ -197,7 +210,7 @@ namespace Banshee.Collection
         }     
         
         public virtual string ArtworkId { 
-            get { return CoverArtSpec.CreateArtistAlbumId (ArtistName, AlbumTitle); }
+            get { return CoverArtSpec.CreateArtistAlbumId (AlbumArtist, AlbumTitle); }
         }
 
         public virtual string Genre {
@@ -309,6 +322,23 @@ namespace Banshee.Collection
             set { media_attributes = value; }
         }
         
+        public bool IsMedia (TrackMediaAttributes attr)
+        {
+            return (MediaAttributes & attr) != 0;
+        }
+        
+        public string MediaTypeName {
+            get {
+                if (IsMedia (TrackMediaAttributes.Podcast))
+                    return Catalog.GetString ("Podcast");
+                if (IsMedia (TrackMediaAttributes.VideoStream))
+                    return Catalog.GetString ("Video");
+                if (IsMedia (TrackMediaAttributes.Music))
+                    return Catalog.GetString ("Song");
+                return Catalog.GetString ("Item");
+            }
+        }
+
         // Generates a{sv} of self according to http://wiki.xmms2.xmms.se/index.php/Media_Player_Interfaces#.22Metadata.22
         public IDictionary<string, object> GenerateExportable ()
         {
