@@ -27,6 +27,7 @@
 //
 
 using System;
+using System.Text.RegularExpressions;
 
 using Banshee.Base;
 using Banshee.Collection;
@@ -114,6 +115,7 @@ namespace Banshee.Streaming
 
             track.ArtistName = Choose (file.Tag.JoinedPerformers, track.ArtistName, preferTrackInfo);
             track.AlbumTitle = Choose (file.Tag.Album, track.AlbumTitle, preferTrackInfo);
+            track.AlbumArtist = Choose (file.Tag.FirstAlbumArtist, track.AlbumArtist, preferTrackInfo);
             track.TrackTitle = Choose (file.Tag.Title, track.TrackTitle, preferTrackInfo);
             track.Genre = Choose (file.Tag.FirstGenre, track.Genre, preferTrackInfo);
             track.Composer = Choose (file.Tag.FirstComposer, track.Composer, preferTrackInfo);
@@ -144,7 +146,28 @@ namespace Banshee.Streaming
                         track.ArtistName = Choose ((string)tag.Value, track.ArtistName);
                         break;
                     case CommonTags.Title:
-                        track.TrackTitle = Choose ((string)tag.Value, track.TrackTitle);
+                        //track.TrackTitle = Choose ((string)tag.Value, track.TrackTitle);
+                        string title = Choose ((string)tag.Value, track.TrackTitle);
+
+                        // Try our best to figure out common patterns in poor radio metadata.
+                        // Often only one tag is sent on track changes inside the stream, 
+                        // which is title, and usually contains artist and track title, separated
+                        // with a " - " string.
+                        if (track.IsLive && title.Contains (" - ")) {
+                            string [] parts = Regex.Split (title, " - ");
+                            track.TrackTitle = parts[1].Trim ();
+                            track.ArtistName = parts[0].Trim ();
+
+                            // Often, the title portion contains a postfix with more information
+                            // that will confuse lookups, such as "Talk [Studio Version]".
+                            // Strip out the [] part.
+                            Match match = Regex.Match (track.TrackTitle, "^(.+)[ ]+\\[.*\\]$");
+                            if (match.Groups.Count == 2) {
+                                track.TrackTitle = match.Groups[1].Value;
+                            }
+                        } else {
+                            track.TrackTitle = title;
+                        }
                         break;
                     case CommonTags.Album:
                         track.AlbumTitle = Choose ((string)tag.Value, track.AlbumTitle);
@@ -192,6 +215,11 @@ namespace Banshee.Streaming
                     case CommonTags.StreamType:
                         track.MimeType = (string)tag.Value;
                         break;
+                    case CommonTags.VideoCodec:
+                        if (tag.Value != null) {
+                            track.MediaAttributes |= TrackMediaAttributes.VideoStream;
+                        }
+                        break;
                     /*case CommonTags.AlbumCoverId:
                         foreach(string ext in TrackInfo.CoverExtensions) {
                             string path = Paths.GetCoverArtPath((string) tag.Value, "." + ext);
