@@ -104,7 +104,7 @@ namespace Banshee.Library
         protected virtual string UserJobTitle {
             get {
                 if (user_job_title == null) {
-                    user_job_title = String.Format (Catalog.GetString ("Importing Songs from {0}"), Name);
+                    user_job_title = String.Format (Catalog.GetString ("Importing From {0}"), Name);
                 }
                 return user_job_title;
             }
@@ -124,6 +124,8 @@ namespace Banshee.Library
         public abstract string Name { get; }
 
         public abstract string[] IconNames { get; }
+        
+        public abstract int SortOrder { get; }
 
         public virtual bool CanImport {
             get { return true; }
@@ -138,7 +140,6 @@ namespace Banshee.Library
             importing = true;
             CreateUserJob ();
             ThreadPool.QueueUserWorkItem (ImportCore);
-            DestroyUserJob ();
             importing = false;
         }
         
@@ -147,6 +148,7 @@ namespace Banshee.Library
         private void ImportCore (object o)
         {
             ImportCore ();
+            DestroyUserJob ();
         }
         
         protected abstract void ImportCore ();
