@@ -39,7 +39,8 @@ using Banshee.MediaEngine;
 
 namespace Banshee.PlaybackController
 {
-    public class PlaybackControllerService : IRequiredService, ICanonicalPlaybackController, IPlaybackControllerExportable
+    public class PlaybackControllerService : IRequiredService, ICanonicalPlaybackController, 
+        IPlaybackController, IPlaybackControllerService
     {
         private enum Direction
         {
@@ -56,6 +57,7 @@ namespace Banshee.PlaybackController
         private bool transition_track_started = false;
         private int consecutive_errors;
         private uint error_transition_id;
+        private DateTime source_auto_set_at = DateTime.MinValue;
     
         private PlaybackShuffleMode shuffle_mode;
         private PlaybackRepeatMode repeat_mode;
@@ -66,7 +68,7 @@ namespace Banshee.PlaybackController
         private ITrackModelSource next_source;
         
         private event PlaybackControllerStoppedHandler dbus_stopped;
-        event PlaybackControllerStoppedHandler IPlaybackController.Stopped {
+        event PlaybackControllerStoppedHandler IPlaybackControllerService.Stopped {
             add { dbus_stopped += value; }
             remove { dbus_stopped -= value; }
         }
@@ -89,6 +91,14 @@ namespace Banshee.PlaybackController
                 PlayerEvent.StateChange |
                 PlayerEvent.Error, 
                 true);
+
+            ServiceManager.SourceManager.ActiveSourceChanged += delegate {
+                ITrackModelSource active_source = ServiceManager.SourceManager.ActiveSource as ITrackModelSource;
+                if (active_source != null && source_auto_set_at == source_set_at && !player_engine.IsPlaying ()) {
+                    Source = active_source;
+                    source_auto_set_at = source_set_at;
+                }
+            };
         }
         
         protected virtual void InstantiateStacks ()
@@ -112,7 +122,7 @@ namespace Banshee.PlaybackController
                     EosTransition ();
                        break;
                 case PlayerEvent.Error:
-                    if (++consecutive_errors >= 20) {
+                    if (++consecutive_errors >= 5) {
                         consecutive_errors = 0;
                         player_engine.Close (false);
                         OnStopped ();
@@ -383,7 +393,7 @@ namespace Banshee.PlaybackController
             protected set { current_track = value; }
         }
         
-        protected DateTime source_set_at;
+        protected DateTime source_set_at = DateTime.MinValue;
         public ITrackModelSource Source {
             get { 
                 if (source == null && ServiceManager.SourceManager.DefaultSource is ITrackModelSource) {
