@@ -184,7 +184,9 @@ namespace Banshee.Sources
                 child_sources.Remove (child);
                 
                 if (ServiceManager.SourceManager.ActiveSource == child) {
-                    ServiceManager.SourceManager.SetActiveSource (this);
+                    if (CanActivate) {
+                        ServiceManager.SourceManager.SetActiveSource (this);
+                    }
                 }
                 
                 OnChildSourceRemoved (child);
@@ -231,6 +233,15 @@ namespace Banshee.Sources
             }
         }
         
+        public T GetInheritedProperty<T> (string name)
+        {
+            return Properties.Contains (name)
+                ? Properties.Get<T> (name)
+                : Parent != null 
+                    ? Parent.GetInheritedProperty<T> (name)
+                    : default (T);
+        }
+        
 #endregion
         
 #region Protected Methods
@@ -543,6 +554,16 @@ namespace Banshee.Sources
             set { ConfigurationClient.Set<int> (String.Format ("sources.{0}", ConfigurationId), "status_format", value); }
         }
         
+        public SchemaEntry<T> CreateSchema<T> (string name)
+        {
+            return CreateSchema<T> (name, default(T), null, null);
+        }
+        
+        public SchemaEntry<T> CreateSchema<T> (string name, T defaultValue, string shotDescription, string longDescription)
+        {
+            return new SchemaEntry<T> (String.Format ("sources.{0}", ConfigurationId), name, defaultValue, shotDescription, longDescription); 
+        }
+        
         public void CycleStatusFormat ()
         {
             int new_status_format = CurrentStatusFormat + 1;
