@@ -36,6 +36,7 @@ using Hyena.Data.Gui;
 using Banshee.Sources;
 using Banshee.ServiceStack;
 using Banshee.MediaEngine;
+using Banshee.Playlist;
 
 using Banshee.Gui;
 
@@ -51,6 +52,7 @@ namespace Banshee.Collection.Gui
 
             RulesHint = true;
             RowSensitivePropertyName = "CanPlay";
+            RowBoldPropertyName = "IsPlaying";
             
             ServiceManager.PlayerEngine.ConnectEvent (OnPlayerEvent, PlayerEvent.StateChange);
             
@@ -120,6 +122,31 @@ namespace Banshee.Collection.Gui
             base.OnDragSourceSet ();
             Drag.SourceSetIconName (this, "audio-x-generic");
         }
+        
+        protected override bool OnDragDrop (Gdk.DragContext context, int x, int y, uint time_)
+        {
+            y = TranslateToListY (y);
+            if (Gtk.Drag.GetSourceWidget (context) == this) {
+                PlaylistSource playlist = ServiceManager.SourceManager.ActiveSource as PlaylistSource;
+                if (playlist != null) {
+                    //Gtk.Drag.
+                    int row = GetRowAtY (y);
+                    if (row != GetRowAtY (y + RowHeight / 2)) {
+                        row += 1;
+                    }
+                    
+                    if (playlist.TrackModel.Selection.Contains (row)) {
+                        // can't drop within the selection
+                        return false;
+                    }
+                    
+                    playlist.ReorderSelectedTracks (row);
+                    return true;
+                }
+            }
+            
+            return false;
+        }
 
         protected override void OnDragDataGet (Gdk.DragContext context, SelectionData selection_data, uint info, uint time)
         {
