@@ -65,6 +65,12 @@ namespace Banshee.Gui.Widgets
             ServiceManager.PlayerEngine.TrackIntercept += OnTrackIntercept;
             
             seek_slider.SeekRequested += OnSeekRequested;
+            
+            // Initialize the display if we're paused since we won't get any
+            // events or state change until something actually happens (BGO #536564)
+            if (ServiceManager.PlayerEngine.CurrentState == PlayerState.Paused) {
+                OnPlayerEngineTick ();
+            }
         }
 
         public void Disconnect ()
@@ -143,7 +149,10 @@ namespace Banshee.Gui.Widgets
                             seek_slider.SetIdle ();
                             break;
                         case PlayerState.Idle:
+                            seek_slider.CanSeek = false;
                             if (!transitioning) {
+                                seek_slider.Duration = 0;
+                                seek_slider.SeekValue = 0;
                                 seek_slider.SetIdle ();
                                 stream_position_label.IsContacting = false;
                             }
