@@ -144,12 +144,25 @@ namespace Banshee.Gui
         private void HandleActiveSourceChanged (SourceEventArgs args)
         {
             UpdateActions ();
+            
+            if (last_source != null) {
+                last_source.Updated -= HandleActiveSourceUpdated;
+            }
+            
+            if (ActiveSource != null) {
+                ActiveSource.Updated += HandleActiveSourceUpdated;
+            }
         }
 
         private void HandleEditMenuActivated (object sender, EventArgs args)
         {
             UpdateActions ();
         }
+        
+        private void HandleActiveSourceUpdated (object o, EventArgs args)
+        {
+            UpdateActions (true);
+        }
 
 #endregion
 
@@ -318,14 +331,19 @@ namespace Banshee.Gui
 
         private Source last_source = null;
         private void UpdateActions ()
+        {
+            UpdateActions (false);
+        }
+        
+        private void UpdateActions (bool force)
         {
             Source source = ActionSource;
 
-            if (source != last_source && source != null) {
-                IUnmapableSource unmapable = source as IUnmapableSource;
-                IImportSource import_source = source as IImportSource;
-                SmartPlaylistSource smart_playlist = source as SmartPlaylistSource;
-                PrimarySource primary_source = source as PrimarySource ?? source.Parent as PrimarySource;
+            if ((force || source != last_source) && source != null) {
+                IUnmapableSource unmapable = (source as IUnmapableSource);
+                IImportSource import_source = (source as IImportSource);
+                SmartPlaylistSource smart_playlist = (source as SmartPlaylistSource);
+                PrimarySource primary_source = (source as PrimarySource) ?? (source.Parent as PrimarySource);
 
                 UpdateAction ("UnmapSourceAction", unmapable != null, unmapable != null && unmapable.CanUnmap, source);
                 UpdateAction ("RenameSourceAction", source.CanRename, true, null);
@@ -338,6 +356,16 @@ namespace Banshee.Gui
                 UpdateAction ("NewSmartPlaylistAction", primary_source != null && primary_source.SupportsPlaylists, true, source);
                 /*UpdateAction ("NewSmartPlaylistFromSearchAction", (source is LibrarySource || source.Parent is LibrarySource),
                         !String.IsNullOrEmpty (source.FilterQuery), source);*/
+                    
+                ActionGroup browser_actions = Actions.FindActionGroup ("BrowserView");
+                if (browser_actions != null) {
+                    IFilterableSource filterable_source = source as IFilterableSource;
+                    bool has_browser = filterable_source != null && filterable_source.AvailableFilters.Count > 0;
+                    UpdateAction (browser_actions["BrowserTopAction"], has_browser);
+                    UpdateAction (browser_actions["BrowserLeftAction"], has_browser);
+                    UpdateAction (browser_actions["BrowserVisibleAction"], has_browser);
+                }
+
                 last_source = source;
             }
             
