@@ -72,11 +72,11 @@ namespace Banshee.Gui
                     Catalog.GetString ("Toggle Fullscreen Mode"), OnFullScreen, false),
             });
 
-            Add (new ToggleActionEntry [] {
+            /*Add (new ToggleActionEntry [] {
                 new ToggleActionEntry ("ShowCoverArtAction", null,
                     Catalog.GetString ("Show Cover _Art"), null,
                     Catalog.GetString ("Toggle display of album cover art"), null, false),
-            });
+            });*/
             
             ServiceManager.PlayerEngine.ConnectEvent (OnPlayerEvent, PlayerEvent.StateChange);
             OnFullScreen (null, EventArgs.Empty);
@@ -84,9 +84,8 @@ namespace Banshee.Gui
         
         private void OnPlayerEvent (PlayerEventArgs args)
         {
-            if (((PlayerEventStateChangeArgs)args).Current == PlayerState.Ready && 
-                !ServiceManager.PlayerEngine.SupportsEqualizer) {
-                Actions["View.ShowEqualizerAction"].Sensitive = false;
+            if (((PlayerEventStateChangeArgs)args).Current == PlayerState.Ready) {
+                Actions["View.ShowEqualizerAction"].Sensitive = ServiceManager.PlayerEngine.SupportsEqualizer;
             }
         }
                 
