@@ -41,6 +41,7 @@ using Hyena.Widgets;
 using Banshee.Sources;
 using Banshee.ServiceStack;
 using Banshee.Collection;
+using Banshee.Collection.Database;
 using Banshee.Configuration;
 using Banshee.Gui;
 using Banshee.Collection.Gui;
@@ -49,6 +50,7 @@ namespace Banshee.Sources.Gui
 {
     public class CompositeTrackSourceContents : FilteredListSourceContents, ITrackModelSourceContents
     {
+        // private QueryFilterView<string> genre_view;
         private ArtistListView artist_view;
         private AlbumListView album_view;
         private TrackListView track_view;
@@ -60,62 +62,45 @@ namespace Banshee.Sources.Gui
         protected override void InitializeViews ()
         {
             SetupMainView (track_view = new TrackListView ());
+            // SetupFilterView (genre_view = new QueryFilterView<string> (Catalog.GetString ("Not Set")));
             SetupFilterView (artist_view = new ArtistListView ());
             SetupFilterView (album_view = new AlbumListView ());
         }
         
         protected override void ClearFilterSelections ()
         {
+            // if (genre_view.Model != null) {
+            //     genre_view.Selection.Clear ();
+            // }
+            
             if (artist_view.Model != null) {
                 artist_view.Selection.Clear ();
             }
+            
             if (album_view.Model != null) {
                 album_view.Selection.Clear ();
             }
         }
 
-        public void SetModels (TrackListModel track, IListModel<ArtistInfo> artist, IListModel<AlbumInfo> album)
+        public void SetModels (TrackListModel track, IListModel<ArtistInfo> artist, IListModel<AlbumInfo> album, IListModel<QueryFilterInfo<string>> genre)
         {
             SetModel (track);
             SetModel (artist);
             SetModel (album);
+            // SetModel (genre);
         }
         
         IListView<TrackInfo> ITrackModelSourceContents.TrackView {
             get { return track_view; }
         }
-        
-        IListView<ArtistInfo> ITrackModelSourceContents.ArtistView {
-            get { return artist_view; }
-        }
-        
-        IListView<AlbumInfo> ITrackModelSourceContents.AlbumView {
-            get { return album_view; }
-        }
 
         public TrackListView TrackView {
             get { return track_view; }
         }
-        
-        public ArtistListView ArtistView {
-            get { return artist_view; }
-        }
-        
-        public AlbumListView AlbumView {
-            get { return album_view; }
-        }
-        
+
         public TrackListModel TrackModel {
             get { return (TrackListModel)track_view.Model; }
         }
-        
-        public ArtistListModel ArtistModel {
-            get { return (ArtistListModel)artist_view.Model; }
-        }
-
-        public AlbumListModel AlbumModel {
-            get { return (AlbumListModel)album_view.Model; }
-        }
 
         protected override bool ActiveSourceCanHasBrowser {
             get {
@@ -131,8 +116,8 @@ namespace Banshee.Sources.Gui
 
         public override bool SetSource (ISource source)
         {
-            //Console.WriteLine ("CTSC.set_source 1");
             ITrackModelSource track_source = source as ITrackModelSource;
+            IFilterableSource filterable_source = source as IFilterableSource;
             if (track_source == null) {
                 return false;
             }
@@ -141,29 +126,31 @@ namespace Banshee.Sources.Gui
             
             SetModel (track_view, track_source.TrackModel);
             
-            foreach (IListModel model in track_source.FilterModels) {
-                if (model is IListModel<ArtistInfo>)
-                    SetModel (artist_view, (model as IListModel<ArtistInfo>));
-                else if (model is IListModel<AlbumInfo>)
-                    SetModel (album_view, (model as IListModel<AlbumInfo>));
-                else
-                    Hyena.Log.DebugFormat ("CompositeTrackSourceContents got non-album/artist filter model: {0}", model);
+            if (filterable_source != null && filterable_source.CurrentFilters != null) {
+                foreach (IListModel model in filterable_source.CurrentFilters) {
+                    if (model is IListModel<ArtistInfo>)
+                        SetModel (artist_view, (model as IListModel<ArtistInfo>));
+                    else if (model is IListModel<AlbumInfo>)
+                        SetModel (album_view, (model as IListModel<AlbumInfo>));
+                    // else if (model is IListModel<QueryFilterInfo<string>>)
+                    //    SetModel (genre_view, (model as IListModel<QueryFilterInfo<string>>));
+                    // else
+                    //    Hyena.Log.DebugFormat ("CompositeTrackSourceContents got non-album/artist filter model: {0}", model);
+                }
             }
             
             track_view.HeaderVisible = true;
-            //Console.WriteLine ("CTSC.set_source 2");
             return true;
         }
 
         public override void ResetSource ()
         {
-            //Console.WriteLine ("CTSC.reset_source 1");
             source = null;
             track_view.SetModel (null);
             artist_view.SetModel (null);
             album_view.SetModel (null);
+            // genre_view.SetModel (null);
             track_view.HeaderVisible = false;
-            //Console.WriteLine ("CTSC.reset_source 2");
         }
 
 #endregion
