@@ -56,18 +56,24 @@ namespace Banshee.Sources.Gui
         
         private Stage<TreeIter> notify_stage = new Stage<TreeIter> (2000);
         
-        private TreeStore store;
         private TreeViewColumn focus_column;
         private TreePath highlight_path;
+        private SourceModel store;
         private int current_timeout = -1;
         private bool editing_row = false;
 
         public SourceView ()
         {
             BuildColumns ();
-            BuildModel ();
+            
+            store = new SourceModel ();
+            store.SourceRowInserted += OnSourceRowInserted;
+            store.SourceRowRemoved += OnSourceRowRemoved;
+            store.RowChanged += OnRowChanged;
+            Model = store;
+            
             ConfigureDragAndDrop ();
-            RefreshList ();
+            store.Refresh ();
             ConnectEvents ();
             
             RowSeparatorFunc = RowSeparatorHandler;
@@ -85,31 +91,16 @@ namespace Banshee.Sources.Gui
         
             focus_column = new TreeViewColumn ();
             renderer = new SourceRowRenderer ();
+            renderer.Padding = 5;
             focus_column.PackStart (renderer, true);
-            focus_column.SetCellDataFunc (renderer, new TreeCellDataFunc (SourceCellDataFunc));
+            focus_column.SetCellDataFunc (renderer, new CellLayoutDataFunc (SourceRowRenderer.CellDataHandler));
             AppendColumn (focus_column);
             
             HeadersVisible = false;
         }
         
-        private void BuildModel ()
-        {
-            store = new TreeStore (typeof (Source), typeof (int), typeof (bool));
-            store.SetSortColumnId (1, SortType.Ascending);
-            store.ChangeSortColumn ();
-            Model = store;
-        }
-        
         private void ConnectEvents ()
         {
-            ServiceManager.SourceManager.SourceAdded += delegate (SourceAddedArgs args) {
-                AddSource (args.Source);
-            };
-            
-            ServiceManager.SourceManager.SourceRemoved += delegate (SourceEventArgs args) {
-                RemoveSource (args.Source);
-            };
-            
             ServiceManager.SourceManager.ActiveSourceChanged += delegate (SourceEventArgs args) {
                 ResetSelection ();
             };
@@ -117,7 +108,7 @@ namespace Banshee.Sources.Gui
             ServiceManager.SourceManager.SourceUpdated += delegate (SourceEventArgs args) {
                 Banshee.Base.ThreadAssist.ProxyToMain (delegate {
                     lock (args.Source) {
-                        TreeIter iter = FindSource (args.Source);
+                        TreeIter iter = store.FindSource (args.Source);
                         if (!TreeIter.Zero.Equals (iter)) {
                             store.SetValue (iter, 1, args.Source.Order);
                             QueueDraw ();
@@ -167,12 +158,12 @@ namespace Banshee.Sources.Gui
                 return base.OnButtonPressEvent (press);
             }
 
-            Source source = GetSource (path);
+            Source source = store.GetSource (path);
 
             // From F-Spot's SaneTreeView class
-            int expander_size = (int) StyleGetProperty ("expander-size");
-            int horizontal_separator = (int) StyleGetProperty ("horizontal-separator");
-            bool on_expander = (press.X <= (horizontal_separator * 2 + path.Depth * expander_size));
+            int expander_size = (int)StyleGetProperty ("expander-size");
+            int horizontal_separator = (int)StyleGetProperty ("horizontal-separator");
+            bool on_expander = press.X <= horizontal_separator * 2 + path.Depth * expander_size;
 
             if (on_expander) {
                 bool ret = base.OnButtonPressEvent (press);
@@ -200,6 +191,11 @@ namespace Banshee.Sources.Gui
                 OnPopupMenu ();
                 return true;
             }
+            
+            if (!source.CanActivate) {
+                return false;
+            }
+            
 
             if (press.Button == 1) {
                 if (ServiceManager.SourceManager.ActiveSource != source) {
@@ -242,13 +238,13 @@ namespace Banshee.Sources.Gui
         protected override void OnRowExpanded (TreeIter iter, TreePath path)
         {
             base.OnRowExpanded (iter, path);
-            GetSource (iter).Expanded = true;
+            store.GetSource (iter).Expanded = true;
         }
         
         protected override void OnRowCollapsed (TreeIter iter, TreePath path)
         {
             base.OnRowCollapsed (iter, path);
-            GetSource (iter).Expanded = false;
+            store.GetSource (iter).Expanded = false;
         }
         
         protected override void OnCursorChanged ()
@@ -288,179 +284,44 @@ namespace Banshee.Sources.Gui
         
 #endregion
 
-#region Source <-> Iter Methods
-
-        public Source GetSource (TreeIter iter)
-        {
-            return store.GetValue (iter, 0) as Source;
-        }
-        
-        public Source GetSource (TreePath path)
-        {
-            TreeIter iter;
-        
-            if (store.GetIter (out iter, path)) {
-                return GetSource (iter);
-            }
-        
-            return null;
-        }
-
-        private TreeIter FindSource (Source source)
-        {
-            foreach (TreeIter iter in FindInModel (0, source)) {
-                return iter;
-            }
-            
-            return TreeIter.Zero;
-        }
-        
-        private IEnumerable<TreeIter> FindInModel (int column, object match)
-        {
-            TreeIter iter = TreeIter.Zero;
-            store.GetIterFirst (out iter);
-            return FindInModel (column, match, iter);
-        }
-        
-        private IEnumerable<TreeIter> FindInModel (int column, object match, TreeIter iter)
-        {
-            if (!store.IterIsValid (iter)) {
-                yield break;
-            }
-            
-            do {
-                object result = store.GetValue (iter, column);
-                Type result_type = result != null ? result.GetType () : null;
-                if (result_type != null && ((result_type.IsValueType && result.Equals (match)) || result == match)) {
-                    yield return iter;
-                }
-                
-                if (store.IterHasChild (iter)) {
-                    TreeIter citer = TreeIter.Zero;
-                    store.IterChildren (out citer, iter);
-                    foreach (TreeIter yiter in FindInModel (column, match, citer)) {
-                        if (!yiter.Equals (TreeIter.Zero)) {
-                            yield return yiter;
-                        }
-                    }
-                }
-            } while (store.IterNext (ref iter));
-        }
-        
-        /*private void AddRowSeparator (int order)
-        {
-            TreeIter iter = store.InsertNode (order);
-            
-            store.SetValue (iter, 0, null);
-            store.SetValue (iter, 1, order);
-            store.SetValue (iter, 2, true);
-        }
-        
-        private void ClearRowSeparators ()
-        {
-            Queue<TreeIter> to_remove = new Queue<TreeIter> ();
-            foreach (TreeIter iter in FindInModel (2, true)) {
-                to_remove.Enqueue (iter);
-            }
-            
-            while (to_remove.Count > 0) {
-                TreeIter iter = to_remove.Dequeue ();
-                store.Remove (ref iter);
-            }
-        }*/
-        
-#endregion
-
 #region Add/Remove Sources / SourceManager interaction
 
-        private void AddSource (Source source)
+        private void OnSourceRowInserted (object o, SourceRowEventArgs args)
         {
-            AddSource (source, TreeIter.Zero);
-        }
+            args.Source.UserNotifyUpdated += OnSourceUserNotifyUpdated;
+            
+            if (args.Source.Parent != null && args.Source.Parent.AutoExpand == true) {
+                Expand (args.ParentIter);
+            }
 
-        private void AddSource (Source source, TreeIter parent)
-        {
-            // Don't add duplicates
-            if (!FindSource (source).Equals (TreeIter.Zero)) {
-                return;
+            if (args.Source.Expanded || args.Source.AutoExpand == true) {
+                Expand (args.Iter);
             }
-            
-            // Don't add a child source before its parent
-            if (parent.Equals (TreeIter.Zero) && source.Parent != null) {
-                return;
-            }
-            
-            int position = source.Order;
-            
-            TreeIter iter = parent.Equals (TreeIter.Zero)
-                ? store.InsertNode (position) 
-                : store.InsertNode (parent, position);
-            
-            store.SetValue (iter, 0, source);
-            store.SetValue (iter, 1, source.Order);
-            store.SetValue (iter, 2, false);
-
-            lock (source.Children) {
-                foreach (Source child in source.Children) {
-                    AddSource (child, iter);
-                }
-            }
-            
-            source.ChildSourceAdded += OnSourceChildSourceAdded; 
-            source.ChildSourceRemoved += OnSourceChildSourceRemoved;
-            source.UserNotifyUpdated += OnSourceUserNotifyUpdated;
-           
-            if (source.Expanded || source.AutoExpand == true) {
-                Expand (iter);
-            } else if (source.Parent != null && source.Parent.AutoExpand == true) {
-                Expand (FindSource (source.Parent));
-            }
-            
-            UpdateView ();
-        }
-
-        private void RemoveSource (Source source)
-        {
-            TreeIter iter = FindSource (source);
-            if (!iter.Equals (TreeIter.Zero)) {
-                store.Remove (ref iter);
-            }
-            
-            source.ChildSourceAdded -= OnSourceChildSourceAdded;
-            source.ChildSourceRemoved -= OnSourceChildSourceRemoved;
-            source.UserNotifyUpdated -= OnSourceUserNotifyUpdated;
 
             UpdateView ();
         }
-    
+        
+        private void OnSourceRowRemoved (object o, SourceRowEventArgs args)
+        {
+            args.Source.UserNotifyUpdated -= OnSourceUserNotifyUpdated;
+            UpdateView ();
+        }
+        
+        private void OnRowChanged (object o, RowChangedArgs args)
+        {
+            QueueDraw ();
+        }
+
         private void Expand (TreeIter iter)
         {
             TreePath path = store.GetPath (iter);
             ExpandRow (path, true);
         }
         
-        private void RefreshList ()
-        {
-            store.Clear ();
-            foreach (Source source in ServiceManager.SourceManager.Sources) {
-                AddSource (source);
-            }
-        }
-        
-        private void OnSourceChildSourceAdded (SourceEventArgs args)
-        {
-            AddSource (args.Source, FindSource (args.Source.Parent));
-        }
-        
-        private void OnSourceChildSourceRemoved (SourceEventArgs args)
-        {
-            RemoveSource (args.Source);
-        }
-
         private void OnSourceUserNotifyUpdated (object o, EventArgs args)
         {
             Banshee.Base.ThreadAssist.ProxyToMain (delegate {
-                TreeIter iter = FindSource ((Source)o);
+                TreeIter iter = store.FindSource ((Source)o);
                 if (iter.Equals (TreeIter.Zero)) {
                     return;
                 }
@@ -505,7 +366,7 @@ namespace Banshee.Sources.Gui
         
         public void BeginRenameSource (Source source)
         {
-            TreeIter iter = FindSource (source);
+            TreeIter iter = store.FindSource (source);
             if (iter.Equals (TreeIter.Zero)) {
                 return;
             }
@@ -515,24 +376,9 @@ namespace Banshee.Sources.Gui
             renderer.Editable = false;
         }
         
-        private void SourceCellDataFunc (TreeViewColumn tree_column, CellRenderer cell,  
-            TreeModel tree_model, TreeIter iter)
-        {
-            SourceRowRenderer renderer = (SourceRowRenderer)cell;
-            renderer.view = this;
-            renderer.source = (Source)store.GetValue (iter, 0);
-            renderer.path = store.GetPath (iter);
-            
-            if (renderer.source == null) {
-                return;
-            }
-            
-            renderer.Sensitive = renderer.source.CanActivate;
-        }
-        
         private void ResetSelection ()
         {
-            TreeIter iter = FindSource (ServiceManager.SourceManager.ActiveSource);
+            TreeIter iter = store.FindSource (ServiceManager.SourceManager.ActiveSource);
             
             if (!iter.Equals (TreeIter.Zero)){
                 Selection.SelectIter (iter);
@@ -598,7 +444,8 @@ namespace Banshee.Sources.Gui
         internal Source NewPlaylistSource {
             get {
                 return new_playlist_source ??
-                    new_playlist_source = new PlaylistSource (Catalog.GetString ("New Playlist"), ServiceManager.SourceManager.MusicLibrary.DbId);
+                    new_playlist_source = new PlaylistSource (Catalog.GetString ("New Playlist"), 
+                        ServiceManager.SourceManager.MusicLibrary.DbId);
             }
         }
 
