@@ -177,7 +177,7 @@ namespace Banshee.AudioCd
             AudioCdTrackInfo track = queue.Dequeue ();
 
             user_job.Title = String.Format (Catalog.GetString ("Importing {0} of {1}"), 
-                ++track_index, source.TrackModel.Count);
+                ++track_index, source.DiscModel.EnabledCount);
             status = String.Format("{0} - {1}", track.ArtistName, track.TrackTitle);
             user_job.Status = status;
             
@@ -200,19 +200,10 @@ namespace Banshee.AudioCd
             track.PrimarySource = ServiceManager.SourceManager.MusicLibrary;
             track.Uri = args.Uri;
             
-            if (track.Artist != null) {
-                track.Artist = DatabaseArtistInfo.UpdateOrCreate (track.Artist);
-                track.ArtistId = track.Artist.DbId;
-            }
-            
-            if (track.Album != null && track.AlbumArtist != null) {
-                DatabaseArtistInfo.UpdateOrCreate (track.AlbumArtist);
-                track.Album = DatabaseAlbumInfo.UpdateOrCreate (track.AlbumArtist, track.Album);
-                track.AlbumId = track.Album.DbId;
-            }
+            track.FileSize = Banshee.IO.File.GetSize (track.Uri);
             
             track.Save ();
-            
+
             source.UnlockTrack (track);
             RipNextTrack ();
         }
