@@ -27,6 +27,7 @@
 //
 
 using System;
+using System.Collections.Generic;
 using System.Threading;
 using Mono.Unix;
 
@@ -35,6 +36,7 @@ using Banshee.Base;
 using Banshee.ServiceStack;
 using Banshee.Sources;
 using Banshee.Collection;
+using Banshee.Collection.Database;
 
 using Gtk;
 using Banshee.Gui;
@@ -47,16 +49,27 @@ namespace Banshee.AudioCd
         private AudioCdDiscModel disc_model;
         private SourceMessage query_message;
         
+        
         public AudioCdSource (AudioCdService service, AudioCdDiscModel discModel) 
-            : base (Catalog.GetString ("Audio CD"), discModel.Title, 200)
+            : base (Catalog.GetString ("Audio CD"), discModel.Title, 400)
         {
             this.service = service;
             this.disc_model = discModel;
             
+            Properties.SetString ("TrackView.ColumnControllerXml", String.Format (@"
+                <column-controller>
+                  <column>
+                    <renderer type=""Hyena.Data.Gui.ColumnCellCheckBox"" property=""RipEnabled""/>
+                  </column>
+                  <add-all-defaults />
+                </column-controller>
+            "));
+            
             disc_model.MetadataQueryStarted += OnMetadataQueryStarted;
             disc_model.MetadataQueryFinished += OnMetadataQueryFinished;
+            disc_model.EnabledCountChanged += OnEnabledCountChanged;
             disc_model.LoadModelFromDisc ();
-            
+
             SetupGui ();
         }
         
@@ -69,7 +82,7 @@ namespace Banshee.AudioCd
                 AudioCdTrackInfo playing_track = ServiceManager.PlayerEngine.CurrentTrack as AudioCdTrackInfo;
                 return playing_track != null && playing_track.Model == disc_model;
             }
-        }            
+        }
         
         public void StopPlayingDisc ()
         {
@@ -83,6 +96,7 @@ namespace Banshee.AudioCd
             ClearMessages ();
             disc_model.MetadataQueryStarted -= OnMetadataQueryStarted;
             disc_model.MetadataQueryFinished -= OnMetadataQueryFinished;
+            disc_model.EnabledCountChanged -= OnEnabledCountChanged;
             service = null;
             disc_model = null;
         }
@@ -91,6 +105,11 @@ namespace Banshee.AudioCd
             get { return disc_model; }
         }
         
+        private void OnEnabledCountChanged (object o, EventArgs args)
+        {
+            UpdateActions ();
+        }
+        
         private void OnMetadataQueryStarted (object o, EventArgs args)
         {
             if (query_message != null) {
@@ -114,15 +133,20 @@ namespace Banshee.AudioCd
                 OnUpdated ();
             }
         
-            if (query_message == null) {
-                return;
-            }
-            
             if (disc_model.MetadataQuerySuccess) {
                 DestroyQueryMessage ();
                 if (DiscIsPlaying) {
                     ServiceManager.PlayerEngine.TrackInfoUpdated ();
                 }
+
+                if (AudioCdService.AutoRip.Get ()) {
+                    BeginAutoRip ();
+                }
+
+                return;
+            }
+
+            if (query_message == null) {
                 return;
             }
             
@@ -142,6 +166,29 @@ namespace Banshee.AudioCd
             }
         }
 
+        private void BeginAutoRip ()
+        {
+            // Make sure the album isn't already in the Library
+            TrackInfo track = disc_model[0];
+            int count = ServiceManager.DbConnection.Query<int> (
+                @"SELECT Count(*) FROM CoreTracks, CoreArtists, CoreAlbums WHERE 
+                    CoreTracks.PrimarySourceID = ? AND
+                    CoreTracks.ArtistID = CoreArtists.ArtistID AND 
+                    CoreTracks.AlbumID = CoreAlbums.AlbumID AND 
+                    CoreArtists.Name = ? AND CoreAlbums.Title = ? AND (CoreTracks.Disc = ? OR CoreTracks.Disc = 0)",
+                    ServiceManager.SourceManager.MusicLibrary.DbId,
+                    track.ArtistName, track.AlbumTitle, track.Disc
+            );
+
+            if (count > 0) {
+                SetStatus (Catalog.GetString ("Automatic import off since this album is already in the Music Library."), true, false, null);
+                return;
+            }
+
+            Log.DebugFormat ("Beginning auto rip of {0}", Name);
+            ImportDisc ();
+        }
+
         internal void ImportDisc ()
         {
             AudioCdRipper ripper = null;
@@ -149,6 +196,7 @@ namespace Banshee.AudioCd
             try {
                 if (AudioCdRipper.Supported) {
                     ripper = new AudioCdRipper (this);
+                    ripper.Finished += OnRipperFinished;
                     ripper.Start ();
                 }
             } catch (Exception e) {
@@ -161,9 +209,21 @@ namespace Banshee.AudioCd
             }
         }
 
+        private void OnRipperFinished (object o, EventArgs args)
+        {
+            if (AudioCdService.EjectAfterRipped.Get ()) {
+                Unmap ();
+            }
+        }
+
         internal void DuplicateDisc ()
         {
-            Hyena.Log.Information ("This feature is not implemented yet.", true);
+            try {
+                AudioCdDuplicator.Duplicate (disc_model);
+            } catch (Exception e) {
+                Hyena.Log.Error (Catalog.GetString ("Could not duplicate audio CD"), e.Message, true);
+                Hyena.Log.Exception (e);
+            }
         }
         
         internal void LockAllTracks ()
@@ -351,12 +411,13 @@ namespace Banshee.AudioCd
                 rip_action.Label = String.Format (Catalog.GetString ("Import \u201f{0}\u201d"), title);
                 rip_action.ShortLabel = Catalog.GetString ("Import CD");
                 rip_action.IconName = "media-import-audio-cd";
-                rip_action.Sensitive = AudioCdRipper.Supported;
+                rip_action.Sensitive = AudioCdRipper.Supported && disc_model.EnabledCount > 0;
             }
             
             Gtk.Action duplicate_action = uia_service.GlobalActions["DuplicateDiscAction"];
             if (duplicate_action != null) {
                 duplicate_action.IconName = "media-cdrom";
+                duplicate_action.Visible = AudioCdDuplicator.Supported;
             }
         }
         
