@@ -27,10 +27,14 @@
 //
 
 using System;
+using System.Collections.Generic;
 using Mono.Unix;
 
 using Hyena;
+using Hyena.Data.Sqlite;
 
+using Banshee.Base;
+using Banshee.ServiceStack;
 using Banshee.Collection;
 using Banshee.Collection.Database;
 using Banshee.Playlist;
@@ -42,34 +46,58 @@ namespace Banshee.Daap
 {
     public class DaapPlaylistSource : PlaylistSource
     {
+        private HyenaSqliteCommand insert_track_command = new HyenaSqliteCommand (@"
+            INSERT INTO CorePlaylistEntries (PlaylistID, TrackID) 
+                SELECT ?, TrackID FROM CoreTracks WHERE PrimarySourceID = ? AND ExternalID IN (?)"
+        );
+        
         private DaapSource parent;
         public DAAP.Database Database {
             get { return parent.Database; }
         }
         
-        public DaapPlaylistSource (DAAP.Playlist playlist, int id, DaapSource parent) : base (playlist.Name, parent.DbId)
+        public DaapPlaylistSource (DAAP.Playlist playlist, DaapSource parent) : base (playlist.Name, parent.DbId)
         {
             this.parent = parent;
-            this.Save ();
+            Save ();
             
-            foreach (DAAP.Track track in playlist.Tracks) {
-                if (track != null && parent.TrackMap.ContainsKey (track.Id)) {
-                    Console.WriteLine ("Adding track {0} to {1}", parent.TrackMap [track.Id], DbId);
-                    AddTrack (parent.TrackMap [track.Id]);
-                } else {
-                    Log.Warning ("Can't find track: was either null or not in map.", false);
+            int count = 0;
+            if (playlist.Tracks.Count > 0) {
+                //IList<DAAP.Track> tracks = playlist.Tracks;
+                int [] external_ids = new int [playlist.Tracks.Count];
+                int i = 0;
+                foreach (DAAP.Track track in playlist.Tracks) {
+                    external_ids[i++] = track == null ? -1 : track.Id;
+                    if (track != null) {
+                        count++;
+                    }
+                }
+
+                if (count > 0) {
+                    ServiceManager.DbConnection.Execute (insert_track_command, DbId, parent.DbId, external_ids);
                 }
             }
+            SavedCount = count;
             
-            this.Reload ();
+            ThreadAssist.ProxyToMain (delegate {
+                OnUpdated ();
+            });
         }
         
-        public override bool ShowBrowser {
+        public override bool CanDeleteTracks {
             get { return false; }
         }
         
-        protected override string TypeUniqueId {
-            get { return "daap-playlist"; }
+        public override bool CanAddTracks {
+            get { return false; }
+        }
+        
+        public override bool CanRename {
+            get { return false; }
+        }
+        
+        public override bool CanUnmap {
+            get { return false; }
         }
     }
 }
