@@ -73,7 +73,7 @@ namespace Banshee.Lastfm.Radio
             get { return lastfm; }
         }
 
-        public LastfmSource () : base (lastfm, lastfm, 150)
+        public LastfmSource () : base (lastfm, lastfm, 210)
         {
             account = LastfmCore.Account;
 
@@ -112,10 +112,13 @@ namespace Banshee.Lastfm.Radio
             actions = new LastfmActions (this);
 
             ServiceManager.SourceManager.AddSource (this);
+
+            ServiceManager.Get<DBusCommandService> ().ArgumentPushed += OnCommandLineArgument;
         }
 
         public void Dispose ()
         {
+            ServiceManager.Get<DBusCommandService> ().ArgumentPushed -= OnCommandLineArgument;
             Connection.StateChanged -= HandleConnectionStateChanged;
             Connection.Dispose ();
             actions.Dispose ();
@@ -125,6 +128,18 @@ namespace Banshee.Lastfm.Radio
             account = null;
         }
 
+        private void OnCommandLineArgument (string uri, object value, bool isFile)
+        {
+            if (!isFile || String.IsNullOrEmpty (uri)) {
+                return;
+            }
+            
+            // Handle lastfm:// URIs
+            if (uri.StartsWith ("lastfm://")) {
+                StationSource.CreateFromUrl (this, uri);
+            }
+        }
+
         /*public override void AddChildSource (ChildSource source)
         {
             base.AddChildSource (source);
@@ -208,10 +223,12 @@ namespace Banshee.Lastfm.Radio
         }
 
         private string last_username;
+        private bool last_was_subscriber = false;
         public void SetUserName (string username)
         {
-            if (username != last_username) {
+            if (username != last_username || last_was_subscriber != Connection.Subscriber) {
                 last_username = username;
+                last_was_subscriber = Connection.Subscriber;
                 LastfmSource.LastUserSchema.Set (last_username);
                 ClearChildSources ();
                 sorting = true;
@@ -278,8 +295,6 @@ namespace Banshee.Lastfm.Radio
                 ClearChildSources ();
             }
 
-            Name = (Connection.State == ConnectionState.Connected ) ? lastfm : Catalog.GetString ("Last.fm (Disconnected)");
-
             if (Connection.Connected) {
                 HideStatus ();
             } else {
