@@ -43,7 +43,7 @@ namespace Hyena.Data.Gui
                 (uint)TargetType.ModelSelection);
     }
     
-    public partial class ListView<T> : Widget
+    public partial class ListView<T> : ListViewBase
     {
         private static TargetEntry [] drag_drop_dest_entries = new TargetEntry [] {
             ListViewDragDropTarget.ModelSelection
@@ -166,18 +166,34 @@ namespace Hyena.Data.Gui
         
         private bool OnDragVScrollTimeout ()
         {
-            ScrollTo (vadjustment.Value + (drag_scroll_velocity * drag_scroll_velocity_max));
+            ScrollTo (VadjustmentValue + (drag_scroll_velocity * drag_scroll_velocity_max));
             DragReorderUpdateRow ();
             return true;
         }
         
         private void DragReorderUpdateRow ()
         {
-            int row = GetRowAtY (drag_reorder_motion_y) - 1;
+            int row = GetDragRow (drag_reorder_motion_y);
             if (row != drag_reorder_row_index) {
                 drag_reorder_row_index = row;
                 InvalidateList ();
             }   
         }
+        
+        protected int GetDragRow (int y)
+        {
+            y = TranslateToListY (y);
+            int row = GetRowAtY (y);
+            
+            if (row == -1) {
+                return -1;
+            }
+
+            if (row != GetRowAtY (y + RowHeight / 2)) {
+                row++;
+            }
+
+            return row;
+        }
     }
-}
+}
\ No newline at end of file
