@@ -34,7 +34,7 @@ using Hyena.Gui.Theming;
 
 namespace Hyena.Data.Gui
 {
-    public partial class ListView<T> : Widget
+    public partial class ListView<T> : ListViewBase
     {
         private Rectangle list_rendering_alloc;
         private Rectangle header_rendering_alloc;
@@ -76,6 +76,8 @@ namespace Hyena.Data.Gui
             event_window = new Gdk.Window (GdkWindow, attributes, attributes_mask);
             event_window.UserData = Handle;
             
+            Style = Gtk.Rc.GetStyleByPaths (Settings, "*.GtkTreeView", "*.GtkTreeView", GType);
+            
             OnDragSourceSet ();
             MoveResize (Allocation);
             
@@ -87,7 +89,7 @@ namespace Hyena.Data.Gui
             WidgetFlags &= ~WidgetFlags.Realized;
             
             event_window.UserData = IntPtr.Zero;
-            event_window.Destroy ();
+            Hyena.Gui.GtkWorkarounds.WindowDestroy (event_window);
             event_window = null;
             
             base.OnUnrealized ();
@@ -105,6 +107,11 @@ namespace Hyena.Data.Gui
             event_window.Hide ();
         }
         
+        protected int TranslateToListY (int y)
+        {
+            return y - list_interaction_alloc.Y;
+        }
+        
         private void MoveResize (Rectangle allocation)
         {
             if (Theme == null) {
