@@ -154,8 +154,6 @@ namespace Hyena.Collections
         
         public void Clear (bool raise)
         {
-            focused_index = -1;
-            
             if (ranges.Count <= 0) {
                 return;
             }
@@ -189,6 +187,14 @@ namespace Hyena.Collections
             get { return ranges.Ranges; }
         }
         
+        public int FirstIndex {
+            get { return Count > 0 ? ranges[0] : -1; }
+        }
+        
+        public int LastIndex {
+            get { return Count > 0 ? ranges[Count - 1]: -1; }
+        }
+        
 #if NET_2_0
         public IEnumerator<int> GetEnumerator ()
         {
