@@ -48,6 +48,12 @@ namespace Hyena.Query
             get { return name; }
             set { name = value; }
         }
+        
+        private string property_name;
+        public string PropertyName {
+            get { return property_name; }
+            set { property_name = value; }
+        }
 
         private string label;
         public string Label {
@@ -74,29 +80,30 @@ namespace Hyena.Query
             get { return is_default; }
         }
 
-        public QueryField (string name, string label, string column, params string [] aliases)
-            : this (name, label, column, false, aliases)
+        public QueryField (string name, string propertyName, string label, string column, params string [] aliases)
+            : this (name, propertyName, label, column, false, aliases)
         {
         }
 
-        public QueryField (string name, string label, string column, bool isDefault, params string [] aliases)
-            : this (name, label, column, new Type [] {typeof(StringQueryValue)}, isDefault, aliases)
+        public QueryField (string name, string propertyName, string label, string column, bool isDefault, params string [] aliases)
+            : this (name, propertyName, label, column, new Type [] {typeof(StringQueryValue)}, isDefault, aliases)
         {
         }
 
-        public QueryField (string name, string label, string column, Type valueType, params string [] aliases)
-            : this (name, label, column, new Type [] {valueType}, false, aliases)
+        public QueryField (string name, string propertyName, string label, string column, Type valueType, params string [] aliases)
+            : this (name, propertyName, label, column, new Type [] {valueType}, false, aliases)
         {
         }
 
-        public QueryField (string name, string label, string column, Type [] valueTypes, params string [] aliases)
-            : this (name, label, column, valueTypes, false, aliases)
+        public QueryField (string name, string propertyName, string label, string column, Type [] valueTypes, params string [] aliases)
+            : this (name, propertyName, label, column, valueTypes, false, aliases)
         {
         }
 
-        public QueryField (string name, string label, string column, Type [] valueTypes, bool isDefault, params string [] aliases)
+        public QueryField (string name, string propertyName, string label, string column, Type [] valueTypes, bool isDefault, params string [] aliases)
         {
             this.name = name;
+            this.property_name = propertyName;
             this.label = label;
             this.column = column;
             this.value_types = valueTypes;
@@ -106,6 +113,11 @@ namespace Hyena.Query
             this.no_custom_format = (Column.IndexOf ("{0}") == -1 && Column.IndexOf ("{1}") == -1);
             this.column_lowered = (Column.IndexOf ("Lowered") != -1);
 
+            if (!no_custom_format) {
+                // Ensure we have parens around any custom 'columns' that may be an OR of two columns
+                this.column = String.Format ("({0})", this.column);
+            }
+
             foreach (Type value_type in valueTypes) {
                 QueryValue.AddValueType (value_type);
             }
@@ -125,7 +137,12 @@ namespace Hyena.Query
 
         public string ToSql (Operator op, QueryValue qv)
         {
-            string value = qv.ToSql ();
+            return ToSql (op, qv, false);
+        }
+        
+        public string ToSql (Operator op, QueryValue qv, bool caseSensitive)
+        {
+            string value = qv.ToSql () ?? String.Empty;
 
             if (op == null) op = qv.OperatorSet.First;
 
@@ -133,16 +150,17 @@ namespace Hyena.Query
 
             if (no_custom_format) {
                 if (qv is StringQueryValue) {
-                    if (column_lowered) {
-                        // The column is pre-lowered, only no need to call lower() in SQL
+                    if (column_lowered || !caseSensitive) {
+                        // The column is pre-lowered, no need to call lower() in SQL
                         sb.AppendFormat ("{0} {1}", Column, String.Format (op.SqlFormat, value.ToLower ()));
                     } else {
                         // Match string values literally and against a lower'd version.  Mostly a workaround
                         // the fact that Sqlite's lower() method only works for ASCII (meaning even with this,
                         // we're not getting 100% case-insensitive matching).
-                        sb.AppendFormat ("({0} {1} OR LOWER({0}) {2})", Column,
+                        sb.AppendFormat ("({0} {1} {3} LOWER({0}) {2})", Column,
                             String.Format (op.SqlFormat, value),
-                            String.Format (op.SqlFormat, value.ToLower ())
+                            String.Format (op.SqlFormat, value.ToLower ()),
+                            op.IsNot ? "AND" : "OR"
                         );
                     }
                 } else {
