@@ -41,25 +41,32 @@ namespace Hyena.Query
     public class RelativeTimeSpanQueryValue : TimeSpanQueryValue
     {
         // The SQL operators in these Operators are reversed from normal on purpose
-        public static new readonly Operator GreaterThan        = new Operator ("greaterThan", "< {0}", ">");
-        public static new readonly Operator LessThan           = new Operator ("lessThan", "> {0}", "<");
-        public static new readonly Operator GreaterThanEqual   = new Operator ("greaterThanEquals", "<= {0}", ">=");
-        public static new readonly Operator LessThanEqual      = new Operator ("lessThanEquals", ">= {0}", "<=");
+        public static new readonly Operator GreaterThan        = new Operator ("greaterThan", Catalog.GetString ("more than"), "< {0}", ">");
+        public static new readonly Operator LessThan           = new Operator ("lessThan", Catalog.GetString ("less than"), "> {0}", "<");
+        public static new readonly Operator GreaterThanEqual   = new Operator ("greaterThanEquals", Catalog.GetString ("at least"), "<= {0}", ">=");
+        public static new readonly Operator LessThanEqual      = new Operator ("lessThanEquals", Catalog.GetString ("at most"), ">= {0}", "<=");
 
         protected static new AliasedObjectSet<Operator> operators = new AliasedObjectSet<Operator> (GreaterThan, LessThan, GreaterThanEqual, LessThanEqual);
         public override AliasedObjectSet<Operator> OperatorSet {
             get { return operators; }
         }
+        
+        public static RelativeTimeSpanQueryValue RelativeToNow (DateTime since)
+        {
+            RelativeTimeSpanQueryValue qv = new RelativeTimeSpanQueryValue ();
+            qv.SetRelativeValue ((since - DateTime.Now).TotalSeconds, TimeFactor.Second);
+            return qv;
+        }
 
         public override string XmlElementName {
             get { return "date"; }
         }
 
-        public override long Offset {
+        public override double Offset {
             get { return -offset; }
         }
 
-        public override void SetUserRelativeValue (long offset, TimeFactor factor)
+        public override void SetUserRelativeValue (double offset, TimeFactor factor)
         {
             SetRelativeValue (-offset, factor);
         }
@@ -75,7 +82,7 @@ namespace Hyena.Query
             return DateTimeUtil.FromDateTime (DateTime.Now + TimeSpan.FromSeconds ((double) offset)).ToString (System.Globalization.CultureInfo.InvariantCulture);
         }
 
-        protected override string FactorString (TimeFactor factor, int count)
+        protected override string FactorString (TimeFactor factor, double count)
         {
             string translated = base.FactorString (factor, count);
             return (translated == null) ? null : String.Format (Catalog.GetString ("{0} ago"), translated);
