@@ -117,10 +117,11 @@ namespace Hyena.Query
         {
             this.factor = factor;
             this.offset = (long) (offset * (double)factor);
+            DetermineFactor ();
             IsEmpty = false;
         }
 
-        public void LoadString (string val)
+        public override void LoadString (string val)
         {
             try {
                 SetRelativeValue (Convert.ToDouble (val), TimeFactor.Second);
